@@ -140,28 +140,11 @@ class System(object):
     __system_connected = False
     __system_alarm = False
     __system_devices = []
-    __scheduler = None
-    __scheduler_thread = None
-    __scheduler_event = None
 
     def __init__(self, hostname, app_id, user_code, user_email, user_password, panel_id, partition):
         """ Initiate the connection to the Visonic API """
         self.__api = API(hostname, app_id, user_code, user_email, user_password, panel_id, partition)
 
-        #Create schedule
-        self.__scheduler = sched.scheduler(time.time, time.sleep)
-        self.__scheduler_thread = threading.Thread(target=self.__scheduler.run, daemon=True, name="state_schedule_thread")
-
-    def _run_scheduled_func(self, timer_seconds, timer_function, token, func):
-        timer_function(token, func)
-        self.schedule(timer_seconds, timer_function, token, func)
-
-    def schedule(self, timer_seconds, timer_function, token, func):
-        self.__scheduler.enter(timer_seconds, 1, self._run_scheduled_func,(timer_seconds, timer_function, token, func))
-
-        if not self.__scheduler_thread.isAlive():
-            self.__scheduler_thread.start()
-
     # System properties
     @property
     def serial_number(self):
@@ -218,44 +201,15 @@ class System(object):
 
     def disarm(self):
         """ Send Disarm command to the alarm system. """
-        res = self.__api.disarm(self.__api.partition)
-
-        self.ProcessStatus(res['process_token'], "DISARM")
+        self.__api.disarm(self.__api.partition)
 
     def arm_home(self):
         """ Send Arm Home command to the alarm system. """
-        res = self.__api.arm_home(self.__api.partition)
-        
-        self.ProcessStatus(res['process_token'], "HOME")
+        self.__api.arm_home(self.__api.partition)
 
     def arm_away(self):
         """ Send Arm Away command to the alarm system. """
-        res = self.__api.arm_away(self.__api.partition)
-        
-        self.ProcessStatus(res['process_token'], "AWAY")
-
-    def ProcessStatus(self, token, function):
-        logging.debug("Calling get_process_status with token " + token)
-        res = self.__api.get_process_status(token)
-        
-        if res == 'handled':
-            if function == 'AWAY':
-                self.__system_state = 'EXITDELAYAWAY'
-            elif function == 'HOME':
-                self.__system_state = 'EXITDELAYHOME'
-            elif function == 'DISARM':
-                self.__system_state = 'ENTRYDELAY'
-
-            time.sleep(1)
-            self.ProcessStatus(token, function)
-        elif res == 'succeeded':
-            self.update_status()
-            
-            logging.debug("Succeded.. updating status" )
-            return
-        else:
-            logging.debug("Stuck processstatus?")
-            return
+        self.__api.arm_away(self.__api.partition)
 
     def connect(self):
         """ Connect to the alarm system and get the static system info. """
@@ -401,11 +355,15 @@ class System(object):
         alarms_events = self.__api.get_alarms()
 
         if alarms_events is None or len(alarms_events) == 0:
-            self.__system_state = partition['state']
-            self.__system_alarm = False
+            if partition['status'] == 'EXIT' and (partition['state'] == 'AWAY' or partition['state'] == 'HOME'):
+                self.__system_state = 'ARMING'
+            else:
+                self.__system_state = partition['state']
+                self.__system_alarm = False
         else:
             state = partition['state']
             self.__system_alarm = True
+
             if state == 'HOME' or state == 'AWAY':
                 self.__system_state = 'ALARM'
             else:
@@ -821,13 +779,11 @@ class API(object):
                                        with_session_token=True)
 
     def get_process_status(self, token):
-        logging.debug(token)
-
         res = self.__send_get_request(self.__url_process_status + '?process_tokens=' + token,
                                        with_user_token=True,
                                        with_session_token=True)
-        logging.debug(res)
-        return res[0]['status']
+
+        return res[0]
 
     def arm_away(self, partition):
         """ Arm in Away mode and with Exit Delay. """
